package com.logicbig.example;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import java.util.Arrays;
import java.util.List;

@Component
public class ExampleClient {

    @Autowired
    private EmployeeRepository repo;

    public void run() {
        List<Employee> employees = createEmployees();
        repo.saveAll(employees);

        System.out.println(" -- finding all employees --");
        Iterable<Employee> all = repo.findAll();
        all.forEach(System.out::println);

        System.out.println(" -- All EmployeeInfo --");
        List<EmployeeInfo> list = repo.findBy();
        for (EmployeeInfo ei : list) {
            EmployeeInfo.DeptInfo di = ei.getDepartment();
            System.out.printf("Name: %s, Salary: %s, Dept: %s%n",
                    ei.getName(), ei.getSalary(), di.getDeptName());
        }

        System.out.println(" -- EmployeeInfo with salary between 3000 and 4000 --");
        list = repo.findBySalaryBetween(3000, 4000);
        for (EmployeeInfo ei : list) {
            EmployeeInfo.DeptInfo di = ei.getDepartment();
            System.out.printf("Name: %s, Salary: %s, Dept: %s%n",
                    ei.getName(), ei.getSalary(), di.getDeptName());
        }

        System.out.println(" -- EmployeeInfo with dept Location TX --");
        list = repo.findByDepartmentLocation("TX");
        for (EmployeeInfo ei : list) {
            EmployeeInfo.DeptInfo di = ei.getDepartment();
            System.out.printf("Name: %s, Salary: %s, Dept: %s%n",
                    ei.getName(), ei.getSalary(), di.getDeptName());
        }
    }

    private List<Employee> createEmployees() {
        return Arrays.asList(
                Employee.of("Diana", Department.of("Admin", "NY"), 3000),
                Employee.of("Mike", Department.of("IT", "TX"), 35000),
                Employee.of("Rose", Department.of("Sales", "NC"), 4000),
                Employee.of("Sara", Department.of("Admin", "TX"), 3500),
                Employee.of("Joe", Department.of("IT", "TX"), 3000),
                Employee.of("Charlie", Department.of("IT", "NY"), 4500)
        );
    }
}